diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/filter/InOperator.php b/core/modules/views/lib/Drupal/views/Plugin/views/filter/InOperator.php
index 14f2ed1..5135a9c 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/filter/InOperator.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/filter/InOperator.php
@@ -29,7 +29,7 @@ class InOperator extends FilterPluginBase {
    * @var array
    * Stores all operations which are available on the form.
    */
-  var $value_options = NULL;
+  protected $valueOptions = NULL;
 
   /**
    * Overrides \Drupal\views\Plugin\views\filter\FilterPluginBase::init().
@@ -37,8 +37,8 @@ class InOperator extends FilterPluginBase {
   public function init(ViewExecutable $view, DisplayPluginBase $display, array &$options = NULL) {
     parent::init($view, $display, $options);
 
-    $this->value_title = t('Options');
-    $this->value_options = NULL;
+    $this->valueTitle = t('Options');
+    $this->valueOptions = NULL;
   }
 
   /**
@@ -50,26 +50,26 @@ public function init(ViewExecutable $view, DisplayPluginBase $display, array &$o
    * possible.
    *
    * @return
    *   Return the stored values in $this->value_options if someone expects it.
    */
   public function getValueOptions() {
-    if (isset($this->value_options)) {
+    if (isset($this->valueOptions)) {
       return;
     }
 
     if (isset($this->definition['options callback']) && is_callable($this->definition['options callback'])) {
       if (isset($this->definition['options arguments']) && is_array($this->definition['options arguments'])) {
-        $this->value_options = call_user_func_array($this->definition['options callback'], $this->definition['options arguments']);
+        $this->valueOptions = call_user_func_array($this->definition['options callback'], $this->definition['options arguments']);
       }
       else {
-        $this->value_options = call_user_func($this->definition['options callback']);
+        $this->valueOptions = call_user_func($this->definition['options callback']);
       }
     }
     else {
-      $this->value_options = array(t('Yes'), t('No'));
+      $this->valueOptions = array(t('Yes'), t('No'));
     }
 
-    return $this->value_options;
+    return $this->valueOptions;
   }
 
   public function defaultExposeOptions() {
@@ -77,8 +77,8 @@ public function defaultExposeOptions() {
     $this->options['expose']['reduce'] = FALSE;
   }
 
-  public function buildExposeForm(&$form, &$form_state) {
-    parent::buildExposeForm($form, $form_state);
+  public function buildExposeForm(&$form, &$formState) {
+    parent::buildExposeForm($form, $formState);
     $form['expose']['reduce'] = array(
       '#type' => 'checkbox',
       '#title' => t('Limit list to selected items'),
@@ -163,24 +163,24 @@ protected function operatorValues($values = 1) {
     return $options;
   }
 
-  protected function valueForm(&$form, &$form_state) {
+  protected function valueForm(&$form, &$formState) {
     $form['value'] = array();
     $options = array();
 
-    if (empty($form_state['exposed'])) {
+    if (empty($formState['exposed'])) {
       // Add a select all option to the value form.
       $options = array('all' => t('Select all'));
     }
 
     $this->getValueOptions();
-    $options += $this->value_options;
-    $default_value = (array) $this->value;
+    $options += $this->valueOptions;
+    $defaultValue = (array) $this->value;
 
     $which = 'all';
     if (!empty($form['operator'])) {
       $source = ':input[name="options[operator]"]';
     }
-    if (!empty($form_state['exposed'])) {
+    if (!empty($formState['exposed'])) {
       $identifier = $this->options['expose']['identifier'];
 
       if (empty($this->options['expose']['use_operator']) || empty($this->options['expose']['operator_id'])) {
@@ -195,21 +195,21 @@ protected function valueForm(&$form, &$form_state) {
         $options = $this->reduceValueOptions();
 
         if (!empty($this->options['expose']['multiple']) && empty($this->options['expose']['required'])) {
-          $default_value = array();
+          $defaultValue = array();
         }
       }
 
       if (empty($this->options['expose']['multiple'])) {
-        if (empty($this->options['expose']['required']) && (empty($default_value) || !empty($this->options['expose']['reduce']))) {
-          $default_value = 'All';
+        if (empty($this->options['expose']['required']) && (empty($defaultValue) || !empty($this->options['expose']['reduce']))) {
+          $defaultValue = 'All';
         }
-        elseif (empty($default_value)) {
+        elseif (empty($defaultValue)) {
           $keys = array_keys($options);
-          $default_value = array_shift($keys);
+          $defaultValue = array_shift($keys);
         }
         else {
-          $copy = $default_value;
-          $default_value = array_shift($copy);
+          $copy = $defaultValue;
+          $defaultValue = array_shift($copy);
         }
       }
     }
@@ -217,19 +217,19 @@ protected function valueForm(&$form, &$form_state) {
     if ($which == 'all' || $which == 'value') {
       $form['value'] = array(
         '#type' => $this->valueFormType,
-        '#title' => $this->value_title,
+        '#title' => $this->valueTitle,
         '#options' => $options,
-        '#default_value' => $default_value,
+        '#default_value' => $defaultValue,
         // These are only valid for 'select' type, but do no harm to checkboxes.
         '#multiple' => TRUE,
         '#size' => count($options) > 8 ? 8 : count($options),
       );
-      if (!empty($form_state['exposed']) && !isset($form_state['input'][$identifier])) {
-        $form_state['input'][$identifier] = $default_value;
+      if (!empty($formState['exposed']) && !isset($formState['input'][$identifier])) {
+        $formState['input'][$identifier] = $defaultValue;
       }
 
       if ($which == 'all') {
-        if (empty($form_state['exposed']) && (in_array($this->valueFormType, array('checkbox', 'checkboxes', 'radios', 'select')))) {
+        if (empty($formState['exposed']) && (in_array($this->valueFormType, array('checkbox', 'checkboxes', 'radios', 'select')))) {
           $form['value']['#prefix'] = '<div id="edit-options-value-wrapper">';
           $form['value']['#suffix'] = '</div>';
         }
@@ -248,7 +248,7 @@ protected function valueForm(&$form, &$form_state) {
    */
   public function reduceValueOptions($input = NULL) {
     if (!isset($input)) {
-      $input = $this->value_options;
+      $input = $this->valueOptions;
     }
 
     // Because options may be an array of strings, or an array of mixed arrays
@@ -293,7 +293,7 @@ public function acceptExposedInput($input) {
     return parent::acceptExposedInput($input);
   }
 
-  protected function valueSubmit($form, &$form_state) {
+  protected function valueSubmit($form, &$formState) {
     // Drupal's FAPI system automatically puts '0' in for any checkbox that
     // was not set, and the key to the checkbox if it is set.
     // Unfortunately, this means that if the key to that checkbox is 0,
@@ -303,7 +303,7 @@ protected function valueSubmit($form, &$form_state) {
     // *only* a list of checkboxes that were set, and we can use that
     // instead.
 
-    $form_state['values']['options']['value'] = $form['value']['#value'];
+    $formState['values']['options']['value'] = $form['value']['#value'];
   }
 
   public function adminSummary() {
@@ -326,7 +326,7 @@ public function adminSummary() {
     if (in_array($this->operator, $this->operatorValues(1))) {
       // Remove every element which is not known.
       foreach ($this->value as $value) {
-        if (!isset($this->value_options[$value])) {
+        if (!isset($this->valueOptions[$value])) {
           unset($this->value[$value]);
         }
       }
@@ -342,8 +342,8 @@ public function adminSummary() {
 
         $keys = $this->value;
         $value = array_shift($keys);
-        if (isset($this->value_options[$value])) {
-          $values = check_plain($this->value_options[$value]);
+        if (isset($this->valueOptions[$value])) {
+          $values = check_plain($this->valueOptions[$value]);
         }
         else {
           $values = '';
@@ -358,8 +358,8 @@ public function adminSummary() {
             $values .= '...';
             break;
           }
-          if (isset($this->value_options[$value])) {
-            $values .= check_plain($this->value_options[$value]);
+          if (isset($this->valueOptions[$value])) {
+            $values .= check_plain($this->valueOptions[$value]);
           }
         }
       }
@@ -412,7 +412,7 @@ public function validate() {
       $errors[] = t('The operator is invalid on filter: @filter.', array('@filter' => $this->adminLabel(TRUE)));
     }
     if (is_array($this->value)) {
-      if (!isset($this->value_options)) {
+      if (!isset($this->valueOptions)) {
         // Don't validate if there are none value options provided, for example for special handlers.
         return $errors;
       }
@@ -422,11 +422,11 @@ public function validate() {
       }
 
       // Some filter_in_operator usage uses optgroups forms, so flatten it.
-      $flat_options = form_options_flatten($this->value_options, TRUE);
+      $flatOptions = form_options_flatten($this->valueOptions, TRUE);
 
       // Remove every element which is not known.
       foreach ($this->value as $value) {
-        if (!isset($flat_options[$value])) {
+        if (!isset($flatOptions[$value])) {
           unset($this->value[$value]);
         }
       }
@@ -50,26 +50,26 @@ public function init(ViewExecutable $view, DisplayPluginBase $display, array &$o
    *
    * @return
-   *   Return the stored values in $this->value_options if someone expects it.
+   *   Return the stored values in $this->valueOptions if someone expects it.
    */
   public function getValueOptions() {
